@@ -6,7 +6,7 @@ use Moo 'with';
 
 with 'Bubblegum::Role::Configuration';
 
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.20'; # VERSION
 
 sub import {
     my $target = caller;
@@ -30,14 +30,14 @@ Bubblegum - Opinionated Modern Perl Development Framework
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
     package Person;
 
     use Bubblegum::Class;
-    use Bubblegum::Syntax -minimal;
+    use Bubblegum::Constraints -minimal;
 
     has 'firstname';
     has 'lastname';
@@ -228,14 +228,14 @@ Perl.
 =head2 Bubblegum Syntax
 
 Additional features and enhancements can be enabled by using the
-L<Bubblegum::Syntax> module which exports type constraint functions, data
+L<Bubblegum::Constraints> module which exports type constraint functions, data
 validation functions and various utility functions. Hardcore Perl hackers around
 the world are working tirelessly around the clock to give us a better system for
 elegantly defining objects and classes using modern Perl best practices, ... but
 in the meantime, have some Bubblegum.
 
     use Bubblegum;
-    use Bubblegum::Syntax 'will';
+    use Bubblegum::Functions 'will';
 
     # take a moment to reason about the following Perl example.
 
@@ -253,7 +253,7 @@ about pushing Perl boundaries.
     package SpaceShip;
 
     use Bubblegum;
-    use Bubblegum::Syntax -minimal;
+    use Bubblegum::Constraints -minimal;
 
     use Function::Parameters;
     use Try::Tiny;
