@@ -1,22 +1,22 @@
 package Bubblegum::Object::Role::Item;
 
 use Bubblegum::Role 'requires';
-use Bubblegum::Syntax -types;
+use Bubblegum::Constraints -types;
 
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.20'; # VERSION
 
 requires 'defined';
 
 sub class {
     my $self = CORE::shift;
-    my $map  = $Bubblegum::Syntax::EXTS;
+    my $map  = $Bubblegum::Constraints::EXTS;
     return $map->{type($self)};
 }
 
 sub of {
     my $self = CORE::shift;
     my $type = type_string CORE::shift;
-    my $map  = $Bubblegum::Syntax::EXTS;
+    my $map  = $Bubblegum::Constraints::EXTS;
 
     my $alias = {
         aref  => 'array',
