@@ -6,18 +6,19 @@ use Bubblegum::Class;
 use Digest::MD5 ();
 use Digest::SHA ();
 
-use Bubblegum::Syntax 'raise';
+use Bubblegum::Exception;
 
 extends 'Bubblegum::Object::Instance';
 
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.20'; # VERSION
 
 
 sub BUILD {
     my $self = shift;
-
-    $self->data->typeof('str') or raise
-        CORE::sprintf q(Wrapper package "%s" requires string data), ref $self;
+    $self->data->typeof('str')
+        or Bubblegum::Exception->throw(
+            ref($self)->format('Wrapper package "%s" requires string data')
+        );
 }
 
 
@@ -52,7 +53,7 @@ Bubblegum::Wrapper::Digest - Bubblegum Wrapper around Hashing Algorithms
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
