@@ -2,25 +2,24 @@
 package Bubblegum::Wrapper::Yaml;
 
 use Bubblegum::Class;
-
-use YAML::Tiny ();
+use Class::Load 'load_class';
 
 extends 'Bubblegum::Object::Instance';
 
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.20'; # VERSION
 
 
 
 sub decode {
     my $self = shift;
-    my $yaml = YAML::Tiny->new;
+    my $yaml = load_class('YAML::Tiny', -version => 1.56)->new;
     return $yaml->read_string($self->data);
 }
 
 
 sub encode {
     my $self = shift;
-    my $yaml = YAML::Tiny->new;
+    my $yaml = load_class('YAML::Tiny', -version => 1.56)->new;
 
     $yaml->[0] = $self->data; # hack
     return $yaml->write_string($self->data);
@@ -40,7 +39,7 @@ Bubblegum::Wrapper::Yaml - Bubblegum Wrapper around YAML Serialization
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
@@ -55,7 +54,9 @@ version 0.19
 
 L<Bubblegum::Wrapper::Yaml> is a Bubblegum wrapper which provides the ability to
 endcode/decode YAML data structures. It is not necessary to use this module as
-it is loaded automatically by the L<Bubblegum> class.
+it is loaded automatically by the L<Bubblegum> class. B<Note>, in order to use
+this wrapper you will need to have L<YAML::Tiny> installed which is not a
+required Bubblegum dependency and should have been installed separately.
 
 =head1 METHODS
 
